Index: uspace/lib/c/generic/as.c
===================================================================
--- uspace/lib/c/generic/as.c	(revision 8d70937197e11be8a09dbc9bd63a588226ddaabb)
+++ uspace/lib/c/generic/as.c	(revision c868e2d76f25a71fcfed3d81a934a16b64b0ce81)
@@ -117,26 +117,15 @@
 /** Find mapping to physical address.
  *
  * @param address Virtual address in question (virtual).
  * @param[out] frame Frame address (physical).
  * @return Error code.
  * @retval EOK No error, @p frame holds the translation.
  * @retval ENOENT Mapping not found.
  */
-int as_get_physical_mapping(const void *address, uintptr_t *frame)
+int as_get_physical_mapping(const void *virt, uintptr_t *phys)
 {
-	uintptr_t tmp_frame;
-	uintptr_t virt = (uintptr_t) address;
-	
-	int rc = (int) __SYSCALL2(SYS_PAGE_FIND_MAPPING,
-	    (sysarg_t) virt, (sysarg_t) &tmp_frame);
-	if (rc != EOK) {
-		return rc;
-	}
-	
-	if (frame != NULL) {
-		*frame = tmp_frame;
-	}
-	
-	return EOK;
+	return (int) __SYSCALL2(SYS_PAGE_FIND_MAPPING, (sysarg_t) virt,
+	    (sysarg_t) phys);
 }
 
@@ -117,26 +117,15 @@
 /** Find mapping to physical address.
  *
- * @param address Virtual address in question (virtual).
- * @param[out] frame Frame address (physical).
- * @return Error code.
- * @retval EOK No error, @p frame holds the translation.
- * @retval ENOENT Mapping not found.
+ * @param      virt Virtual address to find mapping for.
+ * @param[out] phys Physical adress.
+ *
+ * @return EOK on no error.
+ * @retval ENOENT if no mapping was found.
+ *
  */
